@@ -10,6 +10,21 @@ import disruptive.outputs as dtoutputs
 import disruptive.transforms as dttrans
 import disruptive.logging as dtlog
 
+# Event-type constants.
+TOUCH = 'touch'
+TEMPERATURE = 'temperature'
+OBJECT_PRESENT = 'objectPresent'
+HUMIDITY = 'humidity'
+OBJECT_PRESENT_COUNT = 'objectPresentCount'
+TOUCH_COUNT = 'touchCount'
+WATER_PRESENT = 'waterPresent'
+NETWORK_STATUS = 'networkStatus'
+BATTERY_STATUS = 'batteryStatus'
+LABELS_CHANGED = 'labelsChanged'
+CONNECTION_STATUS = 'connectionStatus'
+ETHERNET_STATUS = 'ethernetStatus'
+CELLULAR_STATUS = 'cellularStatus'
+
 
 class _EventData(dtoutputs.OutputBase):
     """
@@ -1461,7 +1476,7 @@ class Event(dtoutputs.OutputBase):
         Unique ID of the source device.
     project_id : str
         Unique ID of the source project.
-    data : :ref:`Event Data`
+    data : :ref:`Event Data <eventdata>`
         An object representing type-specific event data.
 
     """
