@@ -87,6 +87,27 @@ class EventHistory(dtoutputs.OutputBase):
             Object containing each event in history in addition to a few
             convenience functions.
 
+        Examples
+        --------
+        >>> # Fetch all historic events the last 24 hours.
+        >>> history = disruptive.EventHistory.list_events(
+        ...     device_id='<DEVICE_ID>',
+        ...     project_id='<PROJECT_ID',
+        ... )
+        >>> print(history.events_list)
+
+        >>> # Create a datetime object for 7 days ago.
+        >>> from datetime import datetime, timedelta
+        >>> seven_days_ago = datetime.now() - timedelta(7)
+        >>>
+        >>> # Fetch objectPresent event history the last 7 days.
+        ... history = dt.EventHistory.list_events(
+        ...     device_id='<DEVICE_ID>',
+        ...     project_id='<PROJECT_ID>',
+        ...     event_types=['objectPresent'],
+        ...     start_time=seven_days_ago,
+        ... )
+
         """
 
         # Construct URL.
@@ -116,9 +137,9 @@ class EventHistory(dtoutputs.OutputBase):
         # Return list of Event objects of paginated GET response.
         return cls(Event.from_mixed_list(res))
 
-    def get_events(self, event_type):
+    def get_events(self, event_type: str):
         """
-        Returns a filtered list of events specified by type from history.
+        Returns a type-filtered list of events from history.
 
         Parameters
         ----------
@@ -127,7 +148,7 @@ class EventHistory(dtoutputs.OutputBase):
 
         Returns
         -------
-        events : list
+        events : list[Event]
             List of event objects of the specified type.
 
         """
