@@ -78,6 +78,11 @@ class Role(OutputBase):
         role : Role
             Object representing the specified role.
 
+        Examples
+        --------
+        >>> # Fetch information about the project.developer role.
+        >>> role = disruptive.Role.get_role(disruptive.Role.PROJECT_DEVELOPER)
+
         """
 
         # Return list of Role objects.
@@ -108,6 +113,11 @@ class Role(OutputBase):
         roles : list[Role]
             List of objects each representing a role.
 
+        Examples
+        --------
+        >>> # Fetch information about all available roles.
+        >>> roles = disruptive.Role.list_roles()
+
         """
 
         # Return list of Role objects.
